pub enum OptStrategy {
Speed,
Default,
Memory,
}Expand description
Determines the optimization strategy used when there are multiple strategies available for the selected algorithm.
Keyword type: String
Default: OptStrategy::Default
Example: OPT_STRATEGY : Memory
Variants
Speed
Maximizes performance at the cost of additional memory usage.
Default
Balances performance and memory usage.
Memory
Minimizes memory usage at a cost of decreased performance.