pub struct NumBackupIter(pub i32);Expand description
Specifies the number of geometry optimization or molecular dynamics iterations between updates of the backup restart files.
Keyword type: Integer
Default: 5
Example: NUM_BACKUP_ITER : 2
Tuple Fields
0: i32Trait Implementations
Sourceimpl Clone for NumBackupIter
impl Clone for NumBackupIter
Sourcefn clone(&self) -> NumBackupIter
fn clone(&self) -> NumBackupIter
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for NumBackupIter
impl Debug for NumBackupIter
Sourceimpl Default for NumBackupIter
impl Default for NumBackupIter
Sourceimpl FromKeyValue for NumBackupIter
impl FromKeyValue for NumBackupIter
Sourceimpl PartialEq for NumBackupIter
impl PartialEq for NumBackupIter
Sourcefn eq(&self, other: &NumBackupIter) -> bool
fn eq(&self, other: &NumBackupIter) -> bool
self and other values to be equal, and is used by ==.Sourceimpl ToCellValue for NumBackupIter
impl ToCellValue for NumBackupIter
fn to_cell_value(&self) -> CellValue<'_>
impl Copy for NumBackupIter
impl Eq for NumBackupIter
impl StructuralPartialEq for NumBackupIter