pub struct WriteFormattedDensity(pub bool);Expand description
Specifies whether the final electron density is written to an ASCII file.
Keyword type: Logical
Default: FALSE
Example: WRITE_FORMATTED_DENSITY : TRUE
Tuple Fields
0: boolTrait Implementations
Sourceimpl Clone for WriteFormattedDensity
impl Clone for WriteFormattedDensity
Sourcefn clone(&self) -> WriteFormattedDensity
fn clone(&self) -> WriteFormattedDensity
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for WriteFormattedDensity
impl Debug for WriteFormattedDensity
Sourceimpl Default for WriteFormattedDensity
impl Default for WriteFormattedDensity
Sourcefn default() -> WriteFormattedDensity
fn default() -> WriteFormattedDensity
Sourceimpl FromKeyValue for WriteFormattedDensity
impl FromKeyValue for WriteFormattedDensity
Sourceimpl PartialEq for WriteFormattedDensity
impl PartialEq for WriteFormattedDensity
Sourcefn eq(&self, other: &WriteFormattedDensity) -> bool
fn eq(&self, other: &WriteFormattedDensity) -> bool
self and other values to be equal, and is used by ==.Sourceimpl ToCellValue for WriteFormattedDensity
impl ToCellValue for WriteFormattedDensity
fn to_cell_value(&self) -> CellValue<'_>
impl Copy for WriteFormattedDensity
impl Eq for WriteFormattedDensity
impl StructuralPartialEq for WriteFormattedDensity