pub struct GeomMaxIter(pub u32);Expand description
Determines the maximum number of steps in a geometry optimization.
Keyword type: Integer
Default: 30
Example: GEOM_MAX_ITER : 25
Tuple Fields
0: u32Trait Implementations
Sourceimpl Clone for GeomMaxIter
impl Clone for GeomMaxIter
Sourcefn clone(&self) -> GeomMaxIter
fn clone(&self) -> GeomMaxIter
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for GeomMaxIter
impl Debug for GeomMaxIter
Sourceimpl Default for GeomMaxIter
impl Default for GeomMaxIter
Sourceimpl<'de> Deserialize<'de> for GeomMaxIter
impl<'de> Deserialize<'de> for GeomMaxIter
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl FromCellValue for GeomMaxIter
impl FromCellValue for GeomMaxIter
fn from_cell_value(value: &CellValue<'_>) -> CResult<Self>
Sourceimpl FromKeyValue for GeomMaxIter
impl FromKeyValue for GeomMaxIter
Sourceimpl PartialEq for GeomMaxIter
impl PartialEq for GeomMaxIter
Sourcefn eq(&self, other: &GeomMaxIter) -> bool
fn eq(&self, other: &GeomMaxIter) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GeomMaxIter
impl Serialize for GeomMaxIter
Sourceimpl ToCellValue for GeomMaxIter
impl ToCellValue for GeomMaxIter
fn to_cell_value(&self) -> CellValue<'_>
impl Copy for GeomMaxIter
impl Eq for GeomMaxIter
impl StructuralPartialEq for GeomMaxIter