pub struct GeomSpinFix(pub i32);Expand description
Determines the number of geometry optimization steps for which the total spin is fixed.
Keyword type: Integer
Default: 0 (spin is allowed to vary)
Example: GEOM_SPIN_FIX : 5
Tuple Fields
0: i32Trait Implementations
Sourceimpl Clone for GeomSpinFix
impl Clone for GeomSpinFix
Sourcefn clone(&self) -> GeomSpinFix
fn clone(&self) -> GeomSpinFix
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for GeomSpinFix
impl Debug for GeomSpinFix
Sourceimpl Default for GeomSpinFix
impl Default for GeomSpinFix
Sourcefn default() -> GeomSpinFix
fn default() -> GeomSpinFix
Sourceimpl<'de> Deserialize<'de> for GeomSpinFix
impl<'de> Deserialize<'de> for GeomSpinFix
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl FromCellValue for GeomSpinFix
impl FromCellValue for GeomSpinFix
fn from_cell_value(value: &CellValue<'_>) -> CResult<Self>
Sourceimpl FromKeyValue for GeomSpinFix
impl FromKeyValue for GeomSpinFix
Sourceimpl PartialEq for GeomSpinFix
impl PartialEq for GeomSpinFix
Sourcefn eq(&self, other: &GeomSpinFix) -> bool
fn eq(&self, other: &GeomSpinFix) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GeomSpinFix
impl Serialize for GeomSpinFix
Sourceimpl ToCellValue for GeomSpinFix
impl ToCellValue for GeomSpinFix
fn to_cell_value(&self) -> CellValue<'_>
impl Copy for GeomSpinFix
impl Eq for GeomSpinFix
impl StructuralPartialEq for GeomSpinFix